from pydantic import BaseModel
from datetime import datetime
from typing import List, Optional

class RobotBase(BaseModel):
    name: str
    battery_level: int
    last_transfer_date: datetime
    abnormal_drive_status: bool
    location: str
    usage_count: int

class RobotResponse(RobotBase):
    id: int

    class Config:
        from_attributes = True

class BatteryStatusRequest(BaseModel):
    robot_ids: List[int]

class BatteryStatusResponse(BaseModel):
    robot_id: int
    battery_level: int

class LastTransferRequest(BaseModel):
    robot_ids: List[int]

class LastTransferDateResponse(BaseModel):
    robot_id: int
    last_transfer_date: datetime

class LocationRequest(BaseModel):
    robot_ids: List[int]

class LocationResponse(BaseModel):
    robot_id: int
    location_x: float
    location_y: float

class AbnormalDriveResponse(BaseModel):
    robot_ids: List[int]

class NoUsageRobotsResponse(BaseModel):
    robot_ids: List[int]

class LowUsageRobotsResponse(BaseModel):
    robot_ids: List[int]

class DestinationResponse(BaseModel):
    robot_id: int
    destinations: List[str]

class SendSMSRequest(BaseModel):
    message: str
    phone_number: str
